pub fn realisation_id(course_code: &str, kind: RealisationKind) -> StringExpand description
Per (course, kind) rather than per student: a realisation is a shared teaching event whose roster
list-by-course returns.
pub fn realisation_id(course_code: &str, kind: RealisationKind) -> StringPer (course, kind) rather than per student: a realisation is a shared teaching event whose roster
list-by-course returns.